@@ -140,7 +140,7 @@ Proceed with the download?"
         if not self.candidate.downloadable:
             origin = "local_package"
         elif self.candidate.origin == "pearllinux":
-            origin = "pearllinux"
+            origin = "Pearl"
         elif self.candidate.origin.startswith("LP-PPA-"):
             origin = "LP-PPA"
         elif self.apt_origins and self.candidate.origin in self.apt_origins.list():
@@ -174,8 +174,8 @@ Proceed with the download?"
             r = self.check_url(uri)
             if not r:
                 self.exit_on_fail(2)
-        # Pearl Linux repo
-        elif origin == 'pearllinux':
+        # Linux Pearl repo
+        elif origin == 'Pearl':
             # Pearl repos don't have .debian.tar.xz files, only full packages, so
             # check the package cache first
             base_uri, _ = os.path.split(self.candidate.uri)
